pub struct FromToStringCodec;Expand description
A string codec that relies on FromStr and ToString. It can encode anything that
implements ToString and decode anything that implements FromStr.
This makes simple key / value easy to use for primitive types. It is also useful for encoding simply data structures without depending on third party crates like serde and serde_json.
Example
ⓘ
let (get, set, remove) = use_local_storage::<i32, FromToStringCodec>("my-key");Trait Implementations
Sourceimpl<T> Decoder<T> for FromToStringCodecwhere
T: FromStr,
impl<T> Decoder<T> for FromToStringCodecwhere
T: FromStr,