ViaError

Trait ViaError 

pub trait ViaError<E> {
    // Required method
    fn to_server_error(&self) -> ServerFnError<E>;
}
👎Deprecated since 0.8.0:

Now server_fn can return any error type other than ServerFnError, so users should place their custom error type instead of ServerFnError

This trait serves as the conversion method between a variety of types and ServerFnError.

Required Methods

fn to_server_error(&self) -> ServerFnError<E>

👎Deprecated since 0.8.0:

Now server_fn can return any error type other than ServerFnError, so users should place their custom error type instead of ServerFnError

Converts something into an error.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ViaError<NoCustomError> for &&&WrapError<()>

Source

impl<E> ViaError<E> for &&&&WrapError<ServerFnError<E>>
where E: ServerFnErrorKind + Error + Clone,

Source

impl<E> ViaError<E> for &&WrapError<E>
where E: Error + Clone,

Source

impl<E> ViaError<E> for &WrapError<E>
where E: Display + Clone,

Source

impl<E> ViaError<E> for WrapError<E>