WeakOwner

Struct WeakOwner 

pub struct WeakOwner { /* private fields */ }
A weak reference to an Owner that does not prevent cleanup.

This is useful for capturing an owner reference without creating reference cycles that would prevent the owner from being dropped and cleaned up.

Implementations

Source

impl WeakOwner

pub fn upgrade(&self) -> Option<Owner>

Attempts to upgrade this weak reference to a strong Owner.

Returns None if the owner has already been dropped.