pub trait DefinedAt {
// Required method
fn defined_at(&self) -> Option<&'static Location<'static>>;
}Expand description
Describes where the signal was defined. This is used for diagnostic warnings and is purely a debug-mode tool.
Required Methods
Sourcefn defined_at(&self) -> Option<&'static Location<'static>>
fn defined_at(&self) -> Option<&'static Location<'static>>
Returns the location at which the signal was defined. This is usually simply None in
release mode.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".