UntrackableGuard

Trait UntrackableGuard 

pub trait UntrackableGuard: DerefMut {
    // Required method
    fn untrack(&mut self);
}
A reactive, mutable guard that can be untracked to prevent it from notifying subscribers when it is dropped.

Required Methods

fn untrack(&mut self)

Removes the notifier from the guard, such that it will no longer notify subscribers when it is dropped.