pub struct WeakOwner { /* private fields */ }Expand description
A weak reference to an Owner that does not prevent cleanup.
This is useful for capturing an owner reference without creating reference cycles that would prevent the owner from being dropped and cleaned up.
Implementations