pub trait UntrackableGuard: DerefMut {
// Required method
fn untrack(&mut self);
}Expand description
A reactive, mutable guard that can be untracked to prevent it from notifying subscribers when it is dropped.
Required Methods